"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var solidity_parser_antlr_1 = __importDefault(require("solidity-parser-antlr"));
function extendParamsAstWithNatspec(node) {
    if (node.parameters === null) {
        return null;
    }
    return node.parameters.map(function (parameter) { return (__assign(__assign({}, parameter), { natspec: parameter.name === null ||
            node.natspec === null ||
            node.natspec.params === undefined
            ? ''
            : node.natspec.params[parameter.name] })); });
}
function extendReturnParamsAstWithNatspec(node) {
    if (node.returnParameters === null || node.returnParameters === undefined) {
        return null;
    }
    return node.returnParameters.map(function (parameter) { return (__assign(__assign({}, parameter), { natspec: node.natspec === null
            ? ''
            : node.natspec.return })); });
}
/**
 * Prepare for the given file.
 * @param {string} solidityFilePath the file's path to be parsed
 */
function prepareForFile(solidityFilePath) {
    var folder = path_1.default.join(__dirname, '../');
    var input = fs_1.default.readFileSync(solidityFilePath).toString();
    var ast = solidity_parser_antlr_1.default.parse(input);
    var data = {
        events: [],
        functions: [],
    };
    // visit all the methods and add the commands to it
    solidity_parser_antlr_1.default.visit(ast, {
        ContractDefinition: function (node) {
            data = __assign({ contract: node }, data);
        },
        EventDefinition: function (node) {
            data.events.push({
                ast: node,
                parameters: extendParamsAstWithNatspec(node),
                returnParameters: extendReturnParamsAstWithNatspec(node),
            });
        },
        FunctionDefinition: function (node) {
            if (node.isConstructor) {
                data = __assign({ constructor: {
                        ast: node,
                        parameters: extendParamsAstWithNatspec(node),
                        returnParameters: extendReturnParamsAstWithNatspec(node),
                    } }, data);
            }
            else {
                data.functions.push({
                    ast: node,
                    parameters: extendParamsAstWithNatspec(node),
                    returnParameters: extendReturnParamsAstWithNatspec(node),
                });
            }
        },
    });
    var name = ast.children.filter(function (child) { return child.type === 'ContractDefinition'; })[0].name;
    var filename = path_1.default.parse(solidityFilePath).name;
    return {
        data: data,
        filename: filename,
        folder: folder,
        name: name,
        path: solidityFilePath,
    };
}
exports.prepareForFile = prepareForFile;
//# sourceMappingURL=organize.js.map